#loads packages
library(ggplot2)
library(dplyr)
library(tidyr)

#Loads the metagenomic data
ts_dat <- read.table(file="Final MetaG.tsv",
                     header=TRUE,
                     sep="\t")

#Subsets into PLA data only
ts_df <- ts_dat %>%
  filter(Marker == "PLAase")

#Creates taxa ranks for classifications
taxa_ranks <- c("Root", "Domain", "Phylum", "Class",
                "Order", "Family", "Genus", "Species")
ts_df <- ts_df %>%
  separate(col = Taxonomy,
           into = taxa_ranks,
           sep = "; ", fill = "right", remove = T)

#Adds cruise/depth and labels as metagenomic data
ts_df <- ts_df %>% 
  mutate(Sample = gsub("_pe", "_MetaG", Sample)) %>% 
  separate(col = Sample,
           into = c("Cruise", "Depth", "SeqType"),
           extra = "drop")
#Labels entries with no Phyla as uncultured
ts_df <-ts_df %>% mutate(Phylum = replace_na(Phylum, "Uncultured"))

#turns depth into a numeric variable
ts_df <- ts_df %>%
  mutate(Depth.m = as.numeric(gsub('m', '', Depth))) %>% 
  mutate(Cruise = as.numeric(gsub('SI0', '', Cruise)))

#reads the geochemical data for the Saanich Inlet time series
geochem_df <- read.table("Saanich_TimeSeries_Chemical_DATA.csv",
                         header=TRUE, sep=',') %>% 
  filter(Cruise == 72) %>% 
  select(Cruise, Depth,
         CTD_O2, NO3,
         Mean_NH4, Mean_NO2, Mean_H2S, Mean_CH4) %>% 
  mutate(Mean_CH4 = Mean_CH4*1E-3) %>% 
  mutate(across(.fns=as.numeric))

#merges the geochemical data for cruise 72 with the TreeSAPP classifications
ts_geo_df <- left_join(ts_df,
                       geochem_df,
                       by=c("Cruise",
                            "Depth.m" = "Depth"))

#generates relative abundance graph (metagenomic)
ts_geo_df %>% 
  group_by(Depth, Depth.m, SeqType) %>% 
  mutate(Proportion = Abundance/sum(Abundance)) %>% 
  group_by(Depth, Depth.m, Phylum, SeqType) %>% 
  summarise(sum = sum(Proportion)) %>% 
  ungroup() %>% 
  mutate(Depth = reorder(Depth, Depth.m)) %>% 
  ggplot(aes(x=Depth, y=sum, fill=Phylum)) +
  geom_bar(stat = "identity") +
  facet_wrap(~SeqType) +
  labs(x="Depth",
       y="Relative abundance") +
  theme(axis.text.x = element_text(angle = 45, hjust = 1))

#generates total abundance graph (metagenomic)
ts_geo_df %>% 
  group_by(Depth, Depth.m, SeqType) %>% 
  mutate(Proportion = Abundance) %>% 
  group_by(Depth, Depth.m, Phylum, SeqType) %>% 
  summarise(sum = sum(Proportion)) %>% 
  ungroup() %>% 
  mutate(Depth = reorder(Depth, Depth.m)) %>% 
  ggplot(aes(x=Depth, y=sum, fill=Phylum)) +
  geom_bar(stat = "identity") +
  facet_wrap(~SeqType) +
  labs(x="Depth",
       y="Total abundance (TPM)") +
  theme(axis.text.x = element_text(angle = 45, hjust = 1))

#analysis of the chemical profiles of each depth
ts_geo_df %>% 
  pivot_longer(cols=c(starts_with("Mean"), NO3, CTD_O2),
               values_to = "Value.uM",
               names_to = "Molecule") %>%
  ggplot(aes(x=Depth.m, y=Value.uM)) +
  geom_point() +
  geom_line() +
  facet_wrap(~Molecule, scales = "free_x") +
  coord_flip() +
  scale_x_reverse()

#relates metagenomic abundance to oxygen concetrations
ts_geo_df %>% filter(SeqType=="MetaG") %>% filter(!is.na(Phylum)) %>%  mutate(Depth = reorder(Depth, Depth.m)) %>% ggplot(aes(x=Depth, y=Abundance, colour=CTD_O2)) +
geom_boxplot() + geom_point() + facet_wrap(~Phylum) + theme(axis.text.x = element_text(angle = 45, hjust = 1))

#META T STARTS HERE

#Loads the metatranscriptome data and subsets into PLAase
ts_datT <- read.table(file="Final MetaT.tsv",
                     header=TRUE,
                     sep="\t")
ts_dt <- ts_datT %>%
  filter(Marker == "PLAase")

#adds taxa ranks
ts_dt <- ts_dt %>%
  separate(col = Taxonomy,
           into = taxa_ranks,
           sep = "; ", fill = "right", remove = T)

#Adds cruise/depth and labels as metatranscriptomic data
ts_dt <- ts_dt %>% 
  mutate(Sample = gsub("_pe", "_MetaT", Sample)) %>% 
  separate(col = Sample,
           into = c("Cruise", "Depth", "SeqType"),
           extra = "drop")

#Labels entries with no Phyla as uncultured
ts_dt <-ts_dt %>% mutate(Phylum = replace_na(Phylum, "Uncultured"))

#turns depth into a numeric variable
ts_dt <- ts_dt %>%
  mutate(Depth.m = as.numeric(gsub('m', '', Depth))) %>% 
  mutate(Cruise = as.numeric(gsub('SI0', '', Cruise)))

#merges the geochemical data for cruise 72 with the TreeSAPP classifications
ts_geo_dt <- left_join(ts_dt,
                       geochem_df,
                       by=c("Cruise",
                            "Depth.m" = "Depth"))

#generates relative abundance graph
ts_geo_dt %>% 
  group_by(Depth, Depth.m, SeqType) %>% 
  mutate(Proportion = Abundance/sum(Abundance)) %>% 
  group_by(Depth, Depth.m, Phylum, SeqType) %>% 
  summarise(sum = sum(Proportion)) %>% 
  ungroup() %>% 
  mutate(Depth = reorder(Depth, Depth.m)) %>% 
  ggplot(aes(x=Depth, y=sum, fill=Phylum)) +
  geom_bar(stat = "identity") +
  facet_wrap(~SeqType) +
  labs(x="Depth",
       y="Relative abundance") +
  theme(axis.text.x = element_text(angle = 45, hjust = 1))

#generates total abundance graph
ts_geo_dt %>% 
  group_by(Depth, Depth.m, SeqType) %>% 
  mutate(Proportion = Abundance) %>% 
  group_by(Depth, Depth.m, Phylum, SeqType) %>% 
  summarise(sum = sum(Proportion)) %>% 
  ungroup() %>% 
  mutate(Depth = reorder(Depth, Depth.m)) %>% 
  ggplot(aes(x=Depth, y=sum, fill=Phylum)) +
  geom_bar(stat = "identity") +
  facet_wrap(~SeqType) +
  labs(x="Depth",
       y="Total abundance (TPM)") +
  theme(axis.text.x = element_text(angle = 45, hjust = 1))

#relates metatranscriptomic abundance to oxygen concetrations
ts_geo_dt %>% filter(SeqType=="MetaT") %>% filter(!is.na(Phylum)) %>%  mutate(Depth = reorder(Depth, Depth.m)) %>% ggplot(aes(x=Depth, y=Abundance, colour=CTD_O2)) +
  geom_boxplot() + geom_point() + facet_wrap(~Phylum) + theme(axis.text.x = element_text(angle = 45, hjust = 1))